powered by
Methods and functions not in use any more or that have been superseded by renamed functions.
browse(...)Corpus
Corpus
Any arguments that may be passed into the defunct function/method.
An object of class R6ClassGenerator of length 25.
R6ClassGenerator
The RefClass `Corpus` has been superseded by the S4 `corpus`-class and adherent methods.