S4 class for organizing information for concordance output
# S4 method for kwic
show(object)# S4 method for kwic
as.data.frame(x)
# S4 method for kwic
enrich(object, meta = NULL)
# S4 method for kwic
view(.Object)
an object of class kwic
a kwic-class object
sAttributes (character vector) with metainformation
a kwic object
metadataObject of class "character" keeping the sAttributes of the metadata that are to be displayed
leftwords to the left
rightwords to the right
corpusthe CWB corpus
cposthe corpus positions
tableObject of class "data.frame" a table with the relevant information for kwic output
neighborObject of class "character" neighbor, if applicable
encodingObject of class "character" encoding of the corpus
labelsObject of class "character"
categoriesObject of class "character"
indexing for seeing only some concordances
get kwic output